from setuptools import setup, find_packages

from os import path

here = path.abspath((path.dirname(__file__)))

with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()



setup(
    name='coinwise-sdk',
    version=0.1,
    description='CoinWise integration',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/GuilhermeGPG/coinwise-sdk',
    author='Guilherme Gomides',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6'
    ],
    keywords='Coinwise integration',
    author_email='guilhermepgomides@gmail.com',
    license='MIT',
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),
    install_requires=['requests', 'python-status'],
    zip_safe=False
)